@@ -22,6 +22,7 @@ from navability.entities.variable.variable import (
     VariableSkeleton,
     VariableSkeletonSchema,
     VariableSummarySchema,
+    VariableType,
 )
 
 DETAIL_SCHEMA = {
@@ -34,7 +35,7 @@ DETAIL_SCHEMA = {
 logger = logging.getLogger(__name__)
 
 
-async def addVariable(navAbilityClient: NavAbilityClient, client: Client, v: Variable):
+async def _addVariable(navAbilityClient: NavAbilityClient, client: Client, v: Variable):
     result = await navAbilityClient.mutate(
         MutationOptions(
             gql(GQL_ADDVARIABLE),
@@ -44,6 +45,21 @@ async def addVariable(navAbilityClient: NavAbilityClient, client: Client, v: Var
     return result["addVariable"]
 
 
+def addVariable(
+    client: NavAbilityClient, context: Client, variable_or_label, varType=None
+):
+    if isinstance(variable_or_label, Variable):
+        return _addVariable(client, context, variable_or_label)
+    # TODO standardise varType to string or VariableType after design discussion
+    if isinstance(varType, str):
+        v = Variable(variable_or_label, varType)
+        return _addVariable(client, context, v)
+    elif isinstance(varType, VariableType):
+        v = Variable(variable_or_label, varType.value)
+        return _addVariable(client, context, v)
+    raise NotImplementedError()
+
+
 async def listVariables(
     navAbilityClient: NavAbilityClient,
     client: Client,
